@@ -17,7 +17,6 @@ import collections
 import datetime
 
 from dateutil import tz
-import six
 
 from yaql.language import exceptions
 from yaql.language import expressions
@@ -25,20 +24,21 @@ from yaql.language import utils
 from yaql import yaql_interface
 
 
-@six.add_metaclass(abc.ABCMeta)
-class HiddenParameterType(object):
+class HiddenParameterType(metaclass=abc.ABCMeta):
+    __slots__ = tuple()
+
     # noinspection PyMethodMayBeStatic,PyUnusedLocal
     def check(self, value, context, engine, *args, **kwargs):
         return True
 
 
-@six.add_metaclass(abc.ABCMeta)
-class LazyParameterType(object):
-    pass
+class LazyParameterType(metaclass=abc.ABCMeta):
+    __slots__ = tuple()
 
 
-@six.add_metaclass(abc.ABCMeta)
-class SmartType(object):
+class SmartType(metaclass=abc.ABCMeta):
+    __slots__ = ('nullable',)
+
     def __init__(self, nullable):
         self.nullable = nullable
 
@@ -59,8 +59,10 @@ class SmartType(object):
 
 
 class GenericType(SmartType):
+    __slots__ = ('checker', 'converter')
+
     def __init__(self, nullable, checker=None, converter=None):
-        super(GenericType, self).__init__(nullable)
+        super().__init__(nullable)
         self.checker = checker
         self.converter = converter
 
@@ -68,7 +70,7 @@ class GenericType(SmartType):
         if isinstance(value, expressions.Constant):
             value = value.value
 
-        if not super(GenericType, self).check(
+        if not super().check(
                 value, context, engine, *args, **kwargs):
             return False
         if value is None or isinstance(value, expressions.Expression):
@@ -81,7 +83,7 @@ class GenericType(SmartType):
                 *args, **kwargs):
         if isinstance(value, expressions.Constant):
             value = value.value
-        super(GenericType, self).convert(
+        super().convert(
             value, receiver, context, function_spec, engine, *args, **kwargs)
         if value is None or not self.converter:
             return value
@@ -90,6 +92,8 @@ class GenericType(SmartType):
 
 
 class PythonType(GenericType):
+    __slots__ = ('python_type', 'validators')
+
     def __init__(self, python_type, nullable=True, validators=None):
         self.python_type = python_type
         if not validators:
@@ -98,7 +102,7 @@ class PythonType(GenericType):
             validators = [validators]
         self.validators = validators
 
-        super(PythonType, self).__init__(
+        super().__init__(
             nullable,
             lambda value, context, *args, **kwargs: isinstance(
                 value, self.python_type) and all(
@@ -120,44 +124,52 @@ class PythonType(GenericType):
 
 
 class MappingRule(LazyParameterType, SmartType):
+    __slots__ = tuple()
+
     def __init__(self):
-        super(MappingRule, self).__init__(False)
+        super().__init__(False)
 
     def check(self, value, context, *args, **kwargs):
         return isinstance(value, expressions.MappingRuleExpression)
 
     def convert(self, value, receiver, context, function_spec, engine,
                 *args, **kwargs):
-        super(MappingRule, self).convert(
+        super().convert(
             value, receiver, context, function_spec, engine, *args, **kwargs)
-        wrap = lambda func: lambda: func(receiver, context, engine)
+        wrap = lambda func: lambda: func(receiver, context, engine)  # noqa
 
         return utils.MappingRule(wrap(value.source), wrap(value.destination))
 
 
 class String(PythonType):
+    __slots__ = tuple()
+
     def __init__(self, nullable=False):
-        super(String, self).__init__(six.string_types, nullable=nullable)
+        super().__init__(str, nullable=nullable)
 
     def convert(self, value, receiver, context, function_spec, engine,
                 *args, **kwargs):
-        value = super(String, self).convert(
+        value = super().convert(
             value, receiver, context, function_spec, engine, *args, **kwargs)
-        return None if value is None else six.text_type(value)
+        return None if value is None else str(value)
 
 
 class Integer(PythonType):
+    __slots__ = tuple()
+
     def __init__(self, nullable=False):
-        super(Integer, self).__init__(
-            six.integer_types, nullable=nullable,
+        super().__init__(
+            int, nullable=nullable,
             validators=[lambda t: not isinstance(t, bool)])
 
 
 class DateTime(PythonType):
+    __slots__ = tuple()
+
     utctz = tz.tzutc()
 
     def __init__(self, nullable=False):
-        super(DateTime, self).__init__(datetime.datetime, nullable=nullable)
+        super().__init__(datetime.datetime, nullable=nullable)
 
     def convert(self, value, *args, **kwargs):
         if isinstance(value, datetime.datetime):
@@ -165,55 +177,65 @@ class DateTime(PythonType):
                 return value.replace(tzinfo=self.utctz)
             else:
                 return value
-        return super(DateTime, self).convert(value, *args, **kwargs)
+        return super().convert(value, *args, **kwargs)
 
 
 class Iterable(PythonType):
+    __slots__ = tuple()
+
     def __init__(self, validators=None, nullable=False):
-        super(Iterable, self).__init__(
-            collections.Iterable, nullable, [
-                lambda t: not isinstance(t, six.string_types + (
-                    utils.MappingType,))] + (validators or []))
+        super().__init__(
+            collections.abc.Iterable, nullable,
+            [lambda t: not isinstance(t, (str, utils.MappingType))] + (
+                validators or []))
 
     def check(self, value, context, engine, *args, **kwargs):
         if isinstance(value, utils.MappingType) and engine.options.get(
                 'yaql.iterableDicts', False):
             return True
-        return super(Iterable, self).check(
+        return super().check(
             value, context, engine, *args, **kwargs)
 
     def convert(self, value, receiver, context, function_spec, engine,
                 *args, **kwargs):
-        res = super(Iterable, self).convert(
+        res = super().convert(
             value, receiver, context, function_spec, engine, *args, **kwargs)
         return None if res is None else utils.limit_iterable(res, engine)
 
 
 class Iterator(Iterable):
+    __slots__ = tuple()
+
     def __init__(self, validators=None, nullable=False):
-        super(Iterator, self).__init__(
+        super().__init__(
             validators=[utils.is_iterator] + (validators or []),
             nullable=nullable)
 
 
 class Sequence(PythonType):
+    __slots__ = tuple()
+
     def __init__(self, validators=None, nullable=False):
-        super(Sequence, self).__init__(
-            collections.Sequence, nullable, [
-                lambda t: not isinstance(t, six.string_types + (dict,))] + (
+        super().__init__(
+            collections.abc.Sequence, nullable, [
+                lambda t: not isinstance(t, (str, dict))] + (
                     validators or []))
 
 
 class Number(PythonType):
+    __slots__ = tuple()
+
     def __init__(self, nullable=False):
-        super(Number, self).__init__(
-            six.integer_types + (float,), nullable,
+        super().__init__(
+            (int, float), nullable,
             validators=[lambda t: not isinstance(t, bool)])
 
 
 class Lambda(LazyParameterType, SmartType):
+    __slots__ = ('with_context', 'method')
+
     def __init__(self, with_context=False, method=False):
-        super(Lambda, self).__init__(True)
+        super().__init__(True)
         self.with_context = with_context
         self.method = method
 
@@ -221,7 +243,7 @@ class Lambda(LazyParameterType, SmartType):
         if self.method and isinstance(
                 value, expressions.Expression) and not value.uses_receiver:
             return False
-        return super(Lambda, self).check(value, context, *args, **kwargs)
+        return super().check(value, context, *args, **kwargs)
 
     @staticmethod
     def _publish_params(context, args, kwargs):
@@ -234,7 +256,7 @@ class Lambda(LazyParameterType, SmartType):
         self._publish_params(context, args, kwargs)
         if isinstance(value, expressions.Expression):
             result = value(receiver, context, engine)
-        elif six.callable(value):
+        elif callable(value):
             result = value(*args, **kwargs)
         else:
             result = value
@@ -242,12 +264,12 @@ class Lambda(LazyParameterType, SmartType):
 
     def convert(self, value, receiver, context, function_spec, engine,
                 *convert_args, **convert_kwargs):
-        super(Lambda, self).convert(
+        super().convert(
             value, receiver, context, function_spec, engine,
             *convert_args, **convert_kwargs)
         if value is None:
             return None
-        elif six.callable(value) and hasattr(value, '__unwrapped__'):
+        elif callable(value) and hasattr(value, '__unwrapped__'):
             value = value.__unwrapped__
 
         def func(*args, **kwargs):
@@ -273,11 +295,13 @@ class Lambda(LazyParameterType, SmartType):
 
 
 class Super(HiddenParameterType, SmartType):
+    __slots__ = ('with_context', 'method', 'with_name')
+
     def __init__(self, with_context=False, method=None, with_name=False):
         self.with_context = with_context
         self.method = method
         self.with_name = with_name
-        super(Super, self).__init__(False)
+        super().__init__(False)
 
     @staticmethod
     def _find_function_context(spec, context):
@@ -290,7 +314,7 @@ class Super(HiddenParameterType, SmartType):
 
     def convert(self, value, receiver, context, function_spec, engine,
                 *convert_args, **convert_kwargs):
-        if six.callable(value) and hasattr(value, '__unwrapped__'):
+        if callable(value) and hasattr(value, '__unwrapped__'):
             value = value.__unwrapped__
 
         def func(*args, **kwargs):
@@ -326,8 +350,10 @@ class Super(HiddenParameterType, SmartType):
 
 
 class Context(HiddenParameterType, SmartType):
+    __slots__ = tuple()
+
     def __init__(self):
-        super(Context, self).__init__(False)
+        super().__init__(False)
 
     def convert(self, value, receiver, context, function_spec, engine,
                 *args, **kwargs):
@@ -335,9 +361,11 @@ class Context(HiddenParameterType, SmartType):
 
 
 class Delegate(HiddenParameterType, SmartType):
+    __slots__ = ('name', 'with_context', 'method', 'use_convention')
+
     def __init__(self, name=None, with_context=False, method=False,
                  use_convention=True):
-        super(Delegate, self).__init__(False)
+        super().__init__(False)
         self.name = name
         self.with_context = with_context
         self.method = method
@@ -345,7 +373,7 @@ class Delegate(HiddenParameterType, SmartType):
 
     def convert(self, value, receiver, context, function_spec, engine,
                 *convert_args, **convert_kwargs):
-        if six.callable(value) and hasattr(value, '__unwrapped__'):
+        if callable(value) and hasattr(value, '__unwrapped__'):
             value = value.__unwrapped__
 
         def func(*args, **kwargs):
@@ -372,8 +400,10 @@ class Delegate(HiddenParameterType, SmartType):
 
 
 class Receiver(HiddenParameterType, SmartType):
+    __slots__ = tuple()
+
     def __init__(self):
-        super(Receiver, self).__init__(False)
+        super().__init__(False)
 
     def convert(self, value, receiver, context, function_spec, engine,
                 *args, **kwargs):
@@ -381,8 +411,10 @@ class Receiver(HiddenParameterType, SmartType):
 
 
 class Engine(HiddenParameterType, SmartType):
+    __slots__ = tuple()
+
     def __init__(self):
-        super(Engine, self).__init__(False)
+        super().__init__(False)
 
     def convert(self, value, receiver, context, function_spec, engine,
                 *args, **kwargs):
@@ -390,8 +422,10 @@ class Engine(HiddenParameterType, SmartType):
 
 
 class FunctionDefinition(HiddenParameterType, SmartType):
+    __slots__ = tuple()
+
     def __init__(self):
-        super(FunctionDefinition, self).__init__(False)
+        super().__init__(False)
 
     def convert(self, value, receiver, context, function_spec, engine,
                 *args, **kwargs):
@@ -399,25 +433,29 @@ class FunctionDefinition(HiddenParameterType, SmartType):
 
 
 class Constant(SmartType):
+    __slots__ = ('expand',)
+
     def __init__(self, nullable, expand=True):
         self.expand = expand
-        super(Constant, self).__init__(nullable)
+        super().__init__(nullable)
 
     def check(self, value, context, *args, **kwargs):
-        return super(Constant, self).check(
+        return super().check(
             value, context, *args, **kwargs) and (
             value is None or isinstance(value, expressions.Constant))
 
     def convert(self, value, receiver, context, function_spec, engine,
                 *args, **kwargs):
-        super(Constant, self).convert(
+        super().convert(
             value, receiver, context, function_spec, engine, *args, **kwargs)
         return value.value if self.expand else value
 
 
 class YaqlExpression(LazyParameterType, SmartType):
+    __slots__ = ('_expression_types',)
+
     def __init__(self, expression_type=None):
-        super(YaqlExpression, self).__init__(False)
+        super().__init__(False)
         if expression_type and not utils.is_sequence(expression_type):
             expression_type = (expression_type,)
         self._expression_types = expression_type
@@ -429,56 +467,65 @@ class YaqlExpression(LazyParameterType, SmartType):
 
     def convert(self, value, receiver, context, function_spec, engine,
                 *args, **kwargs):
-        super(YaqlExpression, self).convert(
+        super().convert(
             value, receiver, context, function_spec, engine, *args, **kwargs)
         return value
 
 
 class StringConstant(Constant):
+    __slots__ = tuple()
+
     def __init__(self, nullable=False):
-        super(StringConstant, self).__init__(nullable)
+        super().__init__(nullable)
 
     def check(self, value, context, *args, **kwargs):
-        return super(StringConstant, self).check(
+        return super().check(
             value, context, *args, **kwargs) and (
-            value is None or isinstance(value.value, six.string_types))
+            value is None or isinstance(value.value, str))
 
 
 class Keyword(Constant):
+    __slots__ = tuple()
+
     def __init__(self, expand=True):
-        super(Keyword, self).__init__(False, expand)
+        super().__init__(False, expand)
 
     def check(self, value, context, *args, **kwargs):
         return isinstance(value, expressions.KeywordConstant)
 
 
 class BooleanConstant(Constant):
+    __slots__ = tuple()
+
     def __init__(self, nullable=False, expand=True):
-        super(BooleanConstant, self).__init__(nullable, expand)
+        super().__init__(nullable, expand)
 
     def check(self, value, context, *args, **kwargs):
-        return super(BooleanConstant, self).check(
+        return super().check(
             value, context, *args, **kwargs) and (
             value is None or type(value.value) is bool)
 
 
 class NumericConstant(Constant):
+    __slots__ = tuple()
+
     def __init__(self, nullable=False, expand=True):
-        super(NumericConstant, self).__init__(nullable, expand)
+        super().__init__(nullable, expand)
 
     def check(self, value, context, *args, **kwargs):
-        return super(NumericConstant, self).check(
+        return super().check(
             value, context, *args, **kwargs) and (
-            value is None or isinstance(
-                value.value, six.integer_types + (float,)) and
+            value is None or
+            isinstance(value.value, (int, float)) and
             type(value.value) is not bool)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class SmartTypeAggregation(SmartType):
+class SmartTypeAggregation(SmartType, metaclass=abc.ABCMeta):
+    __slots__ = ('types',)
+
     def __init__(self, *args, **kwargs):
         self.nullable = kwargs.pop('nullable', False)
-        super(SmartTypeAggregation, self).__init__(self.nullable)
+        super().__init__(self.nullable)
 
         self.types = []
         for item in args:
@@ -490,6 +537,8 @@ class SmartTypeAggregation(SmartType):
 
 
 class AnyOf(SmartTypeAggregation):
+    __slots__ = tuple()
+
     def _check_match(self, value, context, engine, *args, **kwargs):
         for type_to_check in self.types:
             check_result = type_to_check.check(
@@ -529,6 +578,8 @@ class AnyOf(SmartTypeAggregation):
 
 
 class Chain(SmartTypeAggregation):
+    __slots__ = tuple()
+
     def _check_match(self, value, context, engine, *args, **kwargs):
         for type_to_check in self.types:
             check_result = type_to_check.check(
@@ -568,16 +619,18 @@ class Chain(SmartTypeAggregation):
 
 
 class NotOfType(SmartType):
+    __slots__ = ('smart_type',)
+
     def __init__(self, smart_type, nullable=True):
         if isinstance(smart_type, (type, tuple)):
             smart_type = PythonType(smart_type, nullable=nullable)
         self.smart_type = smart_type
-        super(NotOfType, self).__init__(nullable)
+        super().__init__(nullable)
 
     def check(self, value, context, engine, *args, **kwargs):
         if isinstance(value, expressions.Constant):
             value = value.value
-        if not super(NotOfType, self).check(
+        if not super().check(
                 value, context, engine, *args, **kwargs):
             return False
         if value is None or isinstance(value, expressions.Expression):
@@ -587,8 +640,10 @@ class NotOfType(SmartType):
 
 
 class YaqlInterface(HiddenParameterType, SmartType):
+    __slots__ = tuple()
+
     def __init__(self):
-        super(YaqlInterface, self).__init__(False)
+        super().__init__(False)
 
     def convert(self, value, receiver, context, function_spec, engine,
                 *args, **kwargs):
