@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (c) 2015 Mirantis, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -35,11 +33,11 @@ class TestStrings(yaql.tests.TestCase):
 
     def test_to_upper(self):
         self.assertEqual('QQ', self.eval('qq.toUpper()'))
-        self.assertEqual(u'ПРИВЕТ', self.eval(u'Привет.toUpper()'))
+        self.assertEqual('ПРИВЕТ', self.eval('Привет.toUpper()'))
 
     def test_to_lower(self):
         self.assertEqual('qq', self.eval('QQ.toLower()'))
-        self.assertEqual(u'привет', self.eval(u'Привет.toLower()'))
+        self.assertEqual('привет', self.eval('Привет.toLower()'))
 
     def test_eq(self):
         self.assertTrue(self.eval('a = a'))
@@ -118,10 +116,6 @@ class TestStrings(yaql.tests.TestCase):
     def test_concat_func(self):
         self.assertEqual('abc', self.eval("concat(a, b, c)"))
 
-    def test_format(self):
-        self.assertEqual('a->b', self.eval("'{0}->{x}'.format(a, x => b)"))
-        self.assertEqual('a->b', self.eval("format('{0}->{x}', a, x => b)"))
-
     def test_trim(self):
         self.assertEqual('x', self.eval("'  x  '.trim()"))
         self.assertEqual('x', self.eval("'abxba'.trim(ab)"))
@@ -174,7 +168,7 @@ class TestStrings(yaql.tests.TestCase):
         self.assertEqual(['a', 'b', 'c'], self.eval('abc.toCharArray()'))
 
     def test_characters(self):
-        self.assertItemsEqual(
+        self.assertCountEqual(
             ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'],
             self.eval('characters(octdigits => true, digits => true)'))
 
